@@ -1,6 +1,6 @@
 #
 #  This file is part of MUSIC.
-#  Copyright (C) 2012 Mikael Djurfeldt
+#  Copyright (C) 2012, 2021 Mikael Djurfeldt
 #
 #  MUSIC is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -16,6 +16,6 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from predict_rank import predictRank
-from config import launchedByMusic, supersedeArgv, postponeSetup, \
-                   define, Application, connect, configure, launch
+from .predict_rank import predictRank
+from .config import launchedByMusic, supersedeArgv, postponeSetup, \
+                    define, Application, connect, configure, launch
