@@ -1,6 +1,6 @@
 /*
  *  This file is part of MUSIC.
- *  Copyright (C) 2007, 2008, 2009, 2012 INCF
+ *  Copyright (C) 2007, 2008, 2009, 2012, 2021 INCF
  *
  *  MUSIC is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ namespace MUSIC {
    * This is the syntax of the _MUSIC_CONFIG_ variable:
    *
    * POSTPONE:COLOR means that configuration is postponed until the
-   * first port is created.  At this time, the variable is expected to
+   * first port is created.  At that time, the variable is expected to
    * contain the full configuration information:
    *
    *
@@ -123,11 +123,11 @@ namespace MUSIC {
   {
     std::istringstream env (configStr);
     setName (IOUtils::read (env));
-    env.ignore ();
+    env.ignore (); // delim
     // do not need color information,
     // but we can use for error check
-    env.ignore ();
-    env.ignore ();
+    IOUtils::read (env);
+    env.ignore (); // delim
     applications_->read (env);
     env.ignore ();
     std::map<int, int> leaders = applications_->assignLeaders( Name ());
