@@ -15,12 +15,11 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-//#define MUSIC_DEBUG 1
-#include "music/debug.hh"
-
 #include "music/connection.hh"
 
+#if MUSIC_USE_MPI
+
+
 namespace MUSIC {
 
   OutputConnection::OutputConnection (Connector* connector,
@@ -29,6 +28,7 @@ namespace MUSIC {
     : Connection (connector, maxBuffered),
       elementSize_ (elementSize)
   {
+
   }
 
   InputConnection::InputConnection (Connector* connector,
@@ -38,8 +38,10 @@ namespace MUSIC {
     : Connection (connector, maxBuffered),
       accLatency_ (accLatency),
       interpolate_ (interpolate)
+
   {
   }
 
   
 }
+#endif
