@@ -1,5 +1,6 @@
-#include <mpi.h>
 
+#if MUSIC_USE_MPI
+#include <mpi.h>
 #include "music-c.h"
 
 /* Communicators */
@@ -11,3 +12,4 @@ MUSIC_setupCommunicator (MUSIC_Setup *setup)
 {
   return (MPI_Comm) MUSIC_setupCommunicatorGlue (setup);
 }
+#endif
