@@ -17,9 +17,11 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #include "music/music-config.hh"
 
+#if MUSIC_USE_MPI
+#include <mpi.h>
+
 #if MUSIC_HAVE_SIZE_T
 #include <sys/types.h>
 #else
@@ -58,13 +60,16 @@ MUSIC_EventInputPort *MUSIC_publishEventInput (MUSIC_Setup *setup, char *id);
 MUSIC_MessageOutputPort *MUSIC_publishMessageOutput (MUSIC_Setup *setup, char *id);
 MUSIC_MessageInputPort *MUSIC_publishMessageInput (MUSIC_Setup *setup, char *id);
 
-void MUSIC_destroyContOutput (MUSIC_ContOutputPort* port);
+/* remedius
+ *  Free of the ports is done by the Runtime instance
+ */
+/*void MUSIC_destroyContOutput (MUSIC_ContOutputPort* port);
 void MUSIC_destroyContInput (MUSIC_ContInputPort* port);
 void MUSIC_destroyEventOutput (MUSIC_EventOutputPort* port);
 void MUSIC_destroyEventInput (MUSIC_EventInputPort* port);
 void MUSIC_destroyMessageOutput (MUSIC_MessageOutputPort* port);
 void MUSIC_destroyMessageInput (MUSIC_MessageInputPort* port);
-
+*/
 /* General port methods */
 
 int MUSIC_ContOutputPort_isConnected (MUSIC_ContOutputPort *port);
@@ -199,7 +204,6 @@ double MUSIC_time (MUSIC_Runtime *runtime);
 /* Finalization */
 
 void MUSIC_destroyRuntime (MUSIC_Runtime *runtime);
-
-
+#endif
 #define MUSIC_C_H
 #endif /* MUSIC_C_H */
