@@ -1,6 +1,6 @@
 /*
  *  This file is part of MUSIC.
- *  Copyright (C) 2008, 2009 INCF
+ *  Copyright (C) 2008, 2009, 2022 INCF
  *
  *  MUSIC is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -136,12 +136,12 @@ namespace MUSIC {
   }
 
 
-  SpatialNegotiator::SpatialNegotiator (IndexMap* ind, Index::Type type_, MPI::Intracomm c)
+  SpatialNegotiator::SpatialNegotiator (IndexMap* ind, Index::Type type_, MPI_Comm c)
   : comm(c), indices (ind), type (type_)
   {
 
-	  nProcesses = comm.Get_size ();
-	  localRank = comm.Get_rank ();
+	  nProcesses = mpi_get_comm_size (comm);
+	  localRank = mpi_get_rank (comm);
 	  negotiateWidth ();
 
   }
@@ -167,12 +167,12 @@ namespace MUSIC {
 
     // Now take maximum over all processes
     std::vector<int> m (nProcesses);
-    comm.Allgather (&u, 1, MPI::INT, &m[0], 1, MPI::INT);
+    MPI_Allgather (&u, 1, MPI_INT, &m[0], 1, MPI_INT, comm);
     for (unsigned int i = 0; i < nProcesses; ++i)
       if (m[i] > u)
 	u = m[i];
     width = u;
-    comm.Allgather (&w, 1, MPI::INT, &m[0], 1, MPI::INT);
+    MPI_Allgather (&w, 1, MPI_INT, &m[0], 1, MPI_INT, comm);
     for (unsigned int i = 0; i < nProcesses; ++i)
       if (m[i] > w)
 	w = m[i];
@@ -189,9 +189,9 @@ namespace MUSIC {
     if (localRank == 0)
       {
 	// Receiver might need to know sender width
-	intercomm.Send (&width, 1, MPI::INT, 0, WIDTH_MSG);
+	MPI_Send (&width, 1, MPI_INT, 0, WIDTH_MSG, intercomm);
 	int remoteWidth;
-	intercomm.Recv (&remoteWidth, 1, MPI::INT, 0, WIDTH_MSG);
+	MPI_Recv (&remoteWidth, 1, MPI_INT, 0, WIDTH_MSG, intercomm, MPI_STATUS_IGNORE);
 	if (remoteWidth != width)
 	  {
 	    std::ostringstream msg;
@@ -209,7 +209,7 @@ namespace MUSIC {
     if (localRank == 0)
       {
 	int remoteWidth;
-	intercomm.Recv (&remoteWidth, 1, MPI::INT, 0, WIDTH_MSG);
+	MPI_Recv (&remoteWidth, 1, MPI_INT, 0, WIDTH_MSG, intercomm, MPI_STATUS_IGNORE);
 	// NOTE: For now, the handling of Index::WILDCARD_MAX is a bit
 	// incomplete since, if there is any index interval on the
 	// receiver side with index larger than the sender side width,
@@ -220,10 +220,10 @@ namespace MUSIC {
 	 */
 	if (width == Index::WILDCARD_MAX || width < remoteWidth )
 	  width = remoteWidth;
-	intercomm.Send (&width, 1, MPI::INT, 0, WIDTH_MSG);
+	MPI_Send (&width, 1, MPI_INT, 0, WIDTH_MSG, intercomm);
       }
     // Broadcast result (if we used a wildcard)
-    comm.Bcast (&width, 1, MPI::INT, 0);
+    MPI_Bcast (&width, 1, MPI_INT, 0, comm);
     if (maxLocalWidth_ == Index::WILDCARD_MAX)
       maxLocalWidth_ = width;
   }
@@ -456,36 +456,40 @@ namespace MUSIC {
 
 
   void
-  SpatialNegotiator::send (MPI::Comm& comm,
+  SpatialNegotiator::send (MPI_Comm& comm,
 			   int destRank,
 			   NegotiationIntervals& intervals)
   {
     SpatialNegotiationData* data = &intervals[0];
     int nIntervals = intervals.size ();
     // first send size
-    comm.Send (&nIntervals, 1, MPI::INT, destRank, SPATIAL_NEGOTIATION_MSG);
-    comm.Send (data,
-	       sizeof (SpatialNegotiationData) / sizeof (int) * nIntervals,
-	       MPI::INT,
-	       destRank,
-	       SPATIAL_NEGOTIATION_MSG);
+    MPI_Send (&nIntervals, 1, MPI_INT, destRank, SPATIAL_NEGOTIATION_MSG, comm);
+    MPI_Send (data,
+	      sizeof (SpatialNegotiationData) / sizeof (int) * nIntervals,
+	      MPI_INT,
+	      destRank,
+	      SPATIAL_NEGOTIATION_MSG,
+	      comm);
   }
 
 
   void
-  SpatialNegotiator::receive (MPI::Comm& comm,
+  SpatialNegotiator::receive (MPI_Comm& comm,
 			      int sourceRank,
 			      NegotiationIntervals& intervals)
   {
     int nIntervals;
-    comm.Recv (&nIntervals, 1, MPI::INT, sourceRank, SPATIAL_NEGOTIATION_MSG);
+    MPI_Recv (&nIntervals, 1, MPI_INT, sourceRank, SPATIAL_NEGOTIATION_MSG, comm,
+	      MPI_STATUS_IGNORE);
     intervals.resize (nIntervals);
-    comm.Recv (&intervals[0],
-	       sizeof (SpatialNegotiationData) / sizeof (int)
-	       * nIntervals,
-	       MPI::INT,
-	       sourceRank,
-	       SPATIAL_NEGOTIATION_MSG);
+    MPI_Recv (&intervals[0],
+	      sizeof (SpatialNegotiationData) / sizeof (int)
+	      * nIntervals,
+	      MPI_INT,
+	      sourceRank,
+	      SPATIAL_NEGOTIATION_MSG,
+	      comm,
+	      MPI_STATUS_IGNORE);
   }
 
 
@@ -515,8 +519,8 @@ namespace MUSIC {
   }
 
   SpatialOutputNegotiator::SpatialOutputNegotiator (IndexMap* indices,
-						    Index::Type type, MPI::Intracomm c,
-						    MPI::Intercomm ic)
+						    Index::Type type, MPI_Comm c,
+						    MPI_Comm ic)
       : SpatialNegotiator (indices, type,  c)
   {
 	     intercomm = ic;
@@ -568,8 +572,8 @@ namespace MUSIC {
   }
   
   SpatialInputNegotiator::SpatialInputNegotiator (IndexMap* indices,
-						    Index::Type type, MPI::Intracomm c,
-						    MPI::Intercomm ic)
+						    Index::Type type, MPI_Comm c,
+						    MPI_Comm ic)
       : SpatialNegotiator (indices, type,  c)
   {
 	  intercomm = ic;
