@@ -23,8 +23,7 @@ namespace MUSIC {
   const char*
   version ()
   {
-    // NOTE: take from version.hh which should get it from configure
-    return "1.0.7";
+    return MUSIC_VERSION;
   }
 
 }
