@@ -1,6 +1,6 @@
 /*
  *  This file is part of MUSIC.
- *  Copyright (C) 2008, 2009 INCF
+ *  Copyright (C) 2008, 2009, 2022 INCF
  *
  *  MUSIC is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -149,9 +149,11 @@ main (int argc, char *argv[])
 {
   MUSIC::Setup* setup = new MUSIC::Setup (argc, argv);
   
-  MPI::Intracomm comm = setup->communicator ();
-  int nProcesses = comm.Get_size ();
-  int rank = comm.Get_rank ();
+  MPI_Comm comm = setup->communicator ();
+  int nProcesses;
+  MPI_Comm_size (comm, &nProcesses);
+  int rank;
+  MPI_Comm_rank (comm, &rank);
   
   getargs (rank, argc, argv);
 
@@ -160,7 +162,7 @@ main (int argc, char *argv[])
     {
       if (rank == 0)
 	std::cerr << "eventgenerator port is not connected" << std::endl;
-      comm.Abort (1);
+      MPI_Abort (comm, 1);
     }
 
   MUSIC::Index::Type type;
