@@ -1,6 +1,6 @@
 /*
  *  This file is part of MUSIC.
- *  Copyright (C) 2008, 2009, 2018 INCF
+ *  Copyright (C) 2008, 2009, 2018, 2022 INCF
  *
  *  MUSIC is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -158,9 +158,11 @@ main (int argc, char *argv[])
 {
   MUSIC::Setup* setup = new MUSIC::Setup (argc, argv);
   
-  MPI::Intracomm comm = setup->communicator ();
-  int nProcesses = comm.Get_size ();
-  int rank = comm.Get_rank ();
+  MPI_Comm comm = setup->communicator ();
+  int nProcesses;
+  MPI_Comm_size (comm, &nProcesses);
+  int rank;
+  MPI_Comm_rank (comm, &rank);
   
   getargs (rank, argc, argv);
 
@@ -169,7 +171,7 @@ main (int argc, char *argv[])
     {
       if (rank == 0)
 	std::cerr << "eventsink port is not connected" << std::endl;
-      comm.Abort (1);
+      MPI_Abort (comm, 1);
     }
 
   std::ostringstream spikefile;
@@ -222,7 +224,7 @@ main (int argc, char *argv[])
   setup->config ("stoptime", &stoptime);
 
   if (useBarrier)
-    MPI::COMM_WORLD.Barrier();
+    MPI_Barrier (MPI_COMM_WORLD);
 
   MUSIC::Runtime* runtime = new MUSIC::Runtime (setup, timestep);
 
